package com.ruoyi.frequency.mallordergoods.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.ruoyi.frequency.mallordergoods.entity.MallOrderGoods;

import java.util.List;

/**
 * 订单商品Service接口
 *
 * @author liwenlong
 * @date 2024-01-25
 */
public interface MallOrderGoodsService extends IService<MallOrderGoods>
{
    /**
     * 查询订单商品
     *
     * @param id 订单商品主键
     * @return 订单商品
     */
    public MallOrderGoods selectMallOrderGoodsById(Long id);

    /**
     * 查询订单商品列表
     *
     * @param mallOrderGoods 订单商品
     * @return 订单商品集合
     */
    public List<MallOrderGoods> selectMallOrderGoodsList(MallOrderGoods mallOrderGoods);

    /**
     * 新增订单商品
     *
     * @param mallOrderGoods 订单商品
     * @return 结果
     */
    public int insertMallOrderGoods(MallOrderGoods mallOrderGoods);

    /**
     * 修改订单商品
     *
     * @param mallOrderGoods 订单商品
     * @return 结果
     */
    public int updateMallOrderGoods(MallOrderGoods mallOrderGoods);

    /**
     * 批量删除订单商品
     *
     * @param ids 需要删除的订单商品主键集合
     * @return 结果
     */
    public int deleteMallOrderGoodsByIds(Long[] ids,Integer delFlag);

    List<MallOrderGoods> orderGoodsList(List<Long> orderIdList);
}
